@@ -5,17 +5,17 @@ from task import TaskCommand
 import inspect
 import sys
 
-def create(name, client):
+def create(name, client, rcfile):
     commands = [BoardCommand, UserCommand, ProjectCommand, TaskCommand]
     for c in commands:
         if c.name == name:
-            return c(client)
+            return c(client, rcfile)
     return None
 
-def create_all(client):
+def create_all(client, rcfile):
     commands = [BoardCommand, UserCommand, ProjectCommand, TaskCommand]
     created = []
     for c in commands:
-        created += [c(client)]
+        created += [c(client, rcfile)]
     return created
 
