@@ -11,8 +11,36 @@ import tempfile
 from .command import factory
 from .command.base import CommandError
 
+class KancResourceFile:
+    def __init__(self, filename):
+        self.filename = filename
+        self.rc_dict = {}
+
+    def exists(self):
+        return os.path.exists(self.filename)
+
+    def read(self):
+        if os.path.exists(self.filename):
+            with open(self.filename) as f:
+                rc = f.read()
+            self.rc_dict = json.loads(rc)
+        else:
+            print '.kanrc file not found.'
+            print 'Please type "kanc init" to create .kanrc file first'
+            sys.exit(1)
+
+    def save(self):
+        with open(self.filename, 'w') as f:
+            f.write(json.dumps(self.rc_dict, indent=2))
+
+    def get(self, key):
+        return self.rc_dict[key]
+    
+    def set(self, key, val):
+        self.rc_dict[key] = val
+
 def usage():
-    cmds = factory.create_all(None)
+    cmds = factory.create_all(None, None)
     for cmd in cmds:
         cmd.help()
     sys.exit(2)
@@ -37,23 +65,27 @@ def edit(data):
     return updated_data
 
 def main():
-    try:
-        opts, args = getopt.getopt(sys.argv[1:], 'hjp')
-    except getopt.GetoptError as err:
-        usage()
-
-    json_mode = ('-j', '') in opts
+    args = sys.argv[1:]
     host = None
     apikey = None
 
-    rcfile = os.path.expanduser('~/.kancrc')
+    rcfile = KancResourceFile(os.path.expanduser('~/.kancrc'))
     
     # Show help if no command specified
     if len(args) == 0:
         usage()
 
-    if args[0] == 'init':
-        if os.path.exists(rcfile):
+    # Get command and subcommand
+    cmd_name = args[0]
+    subcmd_name = None
+    cmd_args = []
+    if len(args) > 1:
+        subcmd_name = args[1]
+    if len(args) > 2:
+        cmd_args = args[2:]
+
+    if cmd_name == 'init':
+        if rcfile.exists():
             while True:
                 ans = raw_input('.kanrc file already exists. Overwrite? [y/n]')
                 if ans == 'y':
@@ -64,38 +96,37 @@ def main():
         sys.stdout.write('input your host: ')
         host = sys.stdin.readline().rstrip()
         apikey = getpass.getpass('input your api key: ')
-        with open(rcfile, 'w') as f:
-            rc_dict = {'host': host, 'apikey': apikey, 'patched': True}
-            f.write(json.dumps(rc_dict, indent=2))
+        rcfile.set('host', host)
+        rcfile.set('apikey', apikey)
+        rcfile.set('patched', True)
+        rcfile.set('currentProject', 1)
+        rcfile.save()
         sys.exit(0)
 
-    if os.path.exists(rcfile):
-        with open(rcfile) as f:
-            rc = f.read()
-        rc_dict = json.loads(rc)
-        host = rc_dict['host']
-        apikey = rc_dict['apikey']
-        patched = rc_dict['patched']
+    if rcfile.exists():
+        rcfile.read()
+        host = rcfile.get('host')
+        apikey = rcfile.get('apikey')
     else:
         print '.kanrc file not found.'
         print 'Please type "kanc init" to create .kanrc file first'
         sys.exit(1)
 
-    if patched:
+    if rcfile.get('patched'):
         c = kanpyj.PatchedClient(host, apikey)
     else:
         c = kanpyj.Client(host, apikey)
 
-    if args[0] == 'help':
+    if cmd_name == 'help':
         usage()
-    else:
-        cmd = factory.create(args[0], c)
-        if cmd is None:
-            usage()
-        try:
-            cmd.action(args[1:])
-        except CommandError:
-            cmd.help()
+
+    cmd = factory.create(cmd_name, c, rcfile)
+    if cmd is None:
+        usage()
+    try:
+        cmd.action(subcmd_name, cmd_args)
+    except CommandError:
+        cmd.help()
 
 if __name__ == '__main__':
     main()
